@@ -5,6 +5,10 @@
  *
  */
 
+#if defined(__cplusplus)
+#pragma once
+#endif
+
 #ifndef _ZE_INTEL_RESULTS_H
 #define _ZE_INTEL_RESULTS_H
 
@@ -15,7 +19,7 @@
 #include <cstdint>
 
 // Metrics experimental return codes
-#define ZE_INTEL_RESULT_WARNING_NOT_CALCULABLE_METRICS_IGNORED_EXP static_cast<ze_result_t>(0x40000000) // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange)
-#define ZE_INTEL_RESULT_WARNING_TIME_PARAMS_IGNORED_EXP static_cast<ze_result_t>(0x40000001)            // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange)
+#define ZE_INTEL_RESULT_WARNING_METRICS_EXCLUDED_EXP static_cast<ze_result_t>(0x40000000)    // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange)
+#define ZE_INTEL_RESULT_WARNING_TIME_PARAMS_IGNORED_EXP static_cast<ze_result_t>(0x40000001) // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange)
 
-#endif // _ZE_INTEL_RESULTS_H
\ No newline at end of file
+#endif // _ZE_INTEL_RESULTS_H
